@@ -39,11 +39,12 @@ def dashboards(file_data, sdmonitor, existing_dashboards, restore_unowned):
             ok, res = sdmonitor.get_team(dashboard.get("teamName"))
             if ok:
                 dashboard["teamId"] = res["id"]
-        for setting in dashboard["sharingSettings"]:
-            if setting["member"]["name"] != None:
-                ok, res = sdmonitor.get_team(setting["member"]["name"])
-                if ok:
-                    setting["member"]["id"] = res["id"]
+        if "sharingSettings" in dashboard:
+            for setting in dashboard["sharingSettings"]:
+                if setting["member"]["name"] is not None:
+                    ok, res = sdmonitor.get_team(setting["member"]["name"])
+                    if ok:
+                        setting["member"]["id"] = res["id"]
 
         ok, result = sdmonitor.create_dashboard_with_configuration(dashboard)
         if not ok:
